# Contents
This directory stores a variety of data types used by the application.

**pages**
This directory is used primarily for handling file base routing.

**configs**
This directory is used to store configuration used for managing the application

# Controllers
Install custom routing controllers for applications.

# Resolvers
Dynamically executed python functions

# Plugins
Install custom plugins for applications. Plugins can include
 - parsing any file or assets in the contents directory
